{#-
  This file was automatically generated - do not edit
-#}
<div class="mdl-selectfield">
    <select class="mdl-selectfield__select" id="version-selector" onchange="let pathParts = window.location.pathname.split('/');
        pathParts[1] = this.value;
        window.location.pathname = pathParts.join('/')">
        <option style="color:#fff;background-color:#4b2a5c" value="latest">latest (1.10.x)</option>
        <option style="color:#fff;background-color:#4b2a5c" value="1.10.x">1.10.x</option>
        <option style="color:#fff;background-color:#4b2a5c" value="1.9.x">1.9.x</option>
    </select>
    <script>var pathParts=window.location.pathname.split("/");document.getElementById("version-selector").value=pathParts[1]</script>
</div>
