{#-
  This file was automatically generated - do not edit
-#}
<div class="md-more">
  <input class="md-toggle" data-md-toggle="more" type="checkbox" id="__more" autocomplete="off">
  <ul class="md-more__list">
    <li class="md-more__item">Item 1</li>
    <li class="md-more__item">Item 2</li>
    <li class="md-more__item">Item 3</li>
  </ul>
</div>
